@@ -3,9 +3,9 @@ package Number::ZipCode::JP::Table::Company;
 use strict;
 use warnings;
 
-our $VERSION = '0.20110630';
+our $VERSION = '0.20110729';
 
-# Table last modified: 2011-06-30
+# Table last modified: 2011-07-29
 our %ZIP_TABLE = (
     '001' => '(?:8(?:5(?:[02]1|88)|612))',
     '002' => '(?:850[1-4])',
@@ -67,7 +67,7 @@ our %ZIP_TABLE = (
     '061' => '(?:(?:1(?:49[236-8]|19[2356]|39[2356])|0(?:29[2356]|59[25]|692)|3(?:29[2-6]|197|692)|2292))',
     '062' => '(?:8(?:6(?:55|86|0[1-357-9]|3[0135]|2[24]|4[12]|1[0278]|6[68])|5(?:01|20|7[025]|1[013467]|5[58]|3[029])))',
     '063' => '(?:8(?:5(?:58|0[17]|[18][05])|6(?:41|0[1-36-8]|1[12])))',
-    '064' => '(?:8(?:5(?:1[0-2569]|6[0-7]|0[1-35-79]|2[0-68]|7[0157]|5[0-24-8]|3[0235-7]|8[14-79]|4[0-6])|6(?:68|86|2[0-2489]|0[159]|1[01]|4[124589]|3[039])|798))',
+    '064' => '(?:8(?:5(?:1[0-2569]|6[0-7]|2[0-68]|7[0157]|5[0-24-8]|3[0235-7]|0[1-3569]|8[14-79]|4[0-6])|6(?:68|86|2[0-2489]|0[159]|1[01]|4[124589]|3[039])|798))',
     '065' => '(?:8(?:5(?:[34]3|22|67|78|1[018]|5[058]|0[18])|6(?:86|3[39]|0[19]|1[0-2])))',
     '066' => '(?:8(?:5(?:20|33|1[025]|7[07]|6[67]|8[58]|5[0578]|0[1248])|6(?:01|22|49|55|86|3[379]|6[068]|1[01])|7(?:11|65|87)))',
     '067' => '(?:8(?:5(?:[05]1|47|85|6[45])|674))',
@@ -103,14 +103,14 @@ our %ZIP_TABLE = (
     '097' => '(?:8(?:5(?:10|85|5[58]|2[57])|6(?:[03]9|[68]6)))',
     '098' => '(?:(?:5(?:[78]92|298|595)|(?:28|62|0[13])92|1(?:69[23]|792)|339[23568]))',
     '099' => '(?:(?:2(?:19[2-8]|49[235]|392)|1(?:49[2568]|19[78]|595)|3(?:29[23]|69[78])|4(?:19[256]|492)|(?:56|65)92|049[245]))',
-    '100' => '(?:(?:8(?:9(?:4[015]|8[0-35-79]|6[0-25-9]|7[0-2457-9]|2[0-24-79]|9[46]|3[0137]|1[02-9]|0[1-579]|5[0-3569])|1(?:6\d|0[2358]|4[0149]|5[016-8]|8[0-35-9]|3[0189]|7[1-37]|1[01357-9]|2[0-3568])|6(?:55|86|2[019]|1[057]|3[0-29]|7[067]|6[3568]|0[268]|4[049])|3(?:66|70|5[015]|0[2378]|4[158]|2[1245]|3[138]|1[01]|8[038])|2(?:46|70|6[02578]|2[78]|8[2358]|0[13]|1[014-69]|3[2-4])|5(?:11|43|5[058]|2[02]|6[07]|8[58]|7[57]|0[35-7])|4(?:56|1[015]|2[0147]|0[25]|3[09]|4[048]|8[48])|0(?:19|66|7[07-9]|8[68]|5[01])|79[158])|6(?:1(?:62|7[0-578]|5[0-2])|2(?:55|77|6[02])|0(?:66|80)|75[1-6])|149[28]|3131))',
+    '100' => '(?:(?:8(?:9(?:4[015]|8[0-35-79]|6[0-25-9]|7[0-2457-9]|2[0-24-79]|9[46]|3[0137]|1[02-9]|0[1-579]|5[0-3569])|1(?:3[01589]|8[0-25-9]|6\d|0[2358]|4[0149]|5[016-8]|7[1-37]|1[01357-9]|2[0-3568])|6(?:55|86|2[019]|1[057]|3[0-29]|7[067]|6[3568]|0[268]|4[049])|3(?:66|70|5[015]|0[2378]|4[158]|2[1245]|3[138]|1[01]|8[038])|2(?:46|70|6[02578]|2[78]|8[2358]|0[13]|1[014-69]|3[2-4])|5(?:11|43|5[058]|2[02]|6[07]|8[58]|7[57]|0[35-7])|4(?:02|56|1[015]|2[0147]|3[09]|4[048]|8[48])|0(?:19|66|7[07-9]|8[68]|5[01])|79[158])|6(?:1(?:62|7[0-578]|5[0-2])|2(?:55|77|6[02])|0(?:66|80)|75[1-6])|149[28]|3131))',
     '101' => '(?:8(?:3(?:3[135]|0[1257-9]|8[01358]|6[02356]|7[0158]|5[0-689]|2[1-8]|1[013-7]|4[56])|4(?:7[05-7]|8[13]|0[57-9]|3[03479]|4[13-9]|6[04-9]|5[0-46-9]|2[125]|1[0-25689])|5(?:6[0-2568]|5[289]|4[2-5]|8[1568]|7[6-9]|0[1-46-9]|3[0-5]|1[0-24-69]|2[0-3568])|6(?:8[28]|0[5-79]|6[2578]|3[0346-8]|5[14-6]|4[1-3568]|1[0-479]|7[026]|2[0-24-9])|9(?:[019]1|35|50|7[0-37]|4[16]|8[036])|7(?:0[137]|1[0-25-8])|0(?:11|50|77|0[12])|20[1-4]|101))',
     '102' => '(?:8(?:4(?:5[0-2569]|8[13489]|6[0-24-68]|4[057]|2[014679]|0[125-7]|1[014579]|7[0478]|3[0-3578])|1(?:1[0-278]|5[0-25]|3[0-289]|7[0-25-8]|8[0-24-8]|2[02358]|0[1-359]|4[0-24]|6[016])|6(?:3[0-3579]|4[245]|2[016-8]|8[0589]|7[17-9]|0[1-479]|1[0-47-9]|5[016]|6[06-8])|5(?:5[024-9]|2[0289]|6[079]|3[0139]|8[058]|4[013]|1[01568]|7[013578]|0[2-68])|3(?:4[19]|1[0134]|3[1-356]|8[1-38]|7[0237]|5[035-7]|6[248]|0[1-359]|2[0-24])|2(?:88|5[015]|1[158]|7[257]|2[2568]|3[0-2468]|0[15]|6[0245]|4[016])|0(?:08|77|8[0-35]|1[12568])|79[58]))',
-    '103' => '(?:8(?:2(?:0[1-6]|1[0-2478]|3[0-35-9]|6[0135]|4[0-35-8]|8[57]|7[02358]|2[124589]|5[0-25689])|5(?:0[1-367]|4[2358]|[12][0-25]|5[24-68]|3[013-8]|6[067]|7[0157]|8[4-9])|4(?:3\d|7[0-3]|2[2-7]|0[1-57]|6[0-256]|1[0-79]|8[01467]|5[016]|4[3489])|3(?:7[03]|5[0-2458]|0[136-8]|8[0348]|2[01348]|4[15-7]|1[0137]|6[036]|3[01357-9])|6(?:7[05-7]|6[0568]|3[0-269]|8[0469]|5[0-36]|4[014])|0[01]1))',
-    '104' => '(?:(?:8(?:1(?:2[2-589]|3[0-58]|0[124-689]|5[158]|8[0139]|1[124-8]|4[25]|6[1-8]|7[0-25-8])|4(?:1[01589]|2[0-2459]|4[03-578]|8[168]|0[1-8]|[67][068]|5[0156]|3[013-68])|5(?:1[028]|8[01458]|4[0468]|5[0134689]|7[02]|3[3589]|2[0138]|6[036-8]|0[125])|3(?:6[015]|4[04]|1[0-3579]|2[01458]|5[167]|7[27]|3[02358]|8[038]|0[2-59])|2(?:4[03]|3[38]|2[28]|0[568]|1[0-25]|5[0-35-7]|7[07]|6[026]|8[0-24589])|6(?:50|6[0158]|8[05]|7[08])|0(?:55|77|1[01]|0[1347]))|6241))',
-    '105' => '(?:(?:8(?:4(?:3[24-79]|0[124578]|7[0-37-9]|8[02-8]|1[0-24-689]|5[0-35-8]|2[0-247-9]|4[014-9]|6[01457])|5(?:2[0-357-9]|1[0-2578]|8[0-2457-9]|5[02-8]|0[579]|7[4-9]|4[35689]|6[0378]|3[0457])|6(?:54|6[0568]|1[01348]|4[02]|7[078]|3[014]|8[05-9]|2[1346]|0[3468])|0(?:55|0[12578]|7[07]|8[58]|1[0-2])|3(?:01|22|33|1[0-3])|7(?:0[127]|1[1267]))|7444))',
+    '103' => '(?:8(?:2(?:0[1-6]|1[0-2478]|3[0-35-9]|6[0135]|4[0-35-8]|7[02358]|8[457]|2[124589]|5[0-25689])|5(?:0[1-367]|4[2358]|[12][0-25]|5[24-68]|3[013-8]|6[067]|7[0157]|8[4-9])|4(?:3\d|7[0-3]|2[2-7]|0[1-57]|6[0-256]|1[0-79]|8[01467]|5[016]|4[3489])|3(?:7[03]|5[0-2458]|0[136-8]|8[0348]|2[01348]|4[15-7]|1[0137]|6[036]|3[01357-9])|6(?:7[05-7]|6[0568]|3[0-269]|8[0469]|5[0-36]|4[014])|0[01]1))',
+    '104' => '(?:(?:8(?:1(?:2[2-589]|3[0-58]|0[124-689]|5[158]|8[0139]|1[124-8]|4[25]|6[1-8]|7[0-25-8])|4(?:1[01589]|2[0-2459]|4[03-578]|8[168]|0[1-8]|[67][068]|5[0156]|3[013-68])|5(?:1[028]|8[01458]|4[0468]|5[0134689]|7[02]|3[3589]|2[0138]|6[036-8]|0[1256])|3(?:6[015]|4[04]|1[0-3579]|2[01458]|5[167]|7[27]|3[02358]|8[038]|0[2-59])|2(?:4[03]|1[0-258]|3[38]|2[28]|0[568]|5[0-35-7]|7[07]|6[026]|8[0-24589])|6(?:50|6[0158]|8[05]|7[08])|0(?:55|77|1[01]|0[1347]))|6241))',
+    '105' => '(?:(?:8(?:4(?:3[24-79]|0[124578]|8[02-8]|1[0-24-689]|5[0-35-8]|2[0-247-9]|7[0-39]|4[014-9]|6[01457])|5(?:2[0-357-9]|1[0-2578]|8[0-2457-9]|5[02-8]|0[579]|7[4-9]|4[35689]|6[0378]|3[0457])|6(?:54|6[0568]|1[01348]|4[02]|7[078]|3[014]|8[05-9]|2[1346]|0[3468])|0(?:55|0[12578]|7[07]|8[58]|1[0-2])|3(?:01|22|33|1[0-3])|7(?:0[127]|1[1267]))|7444))',
     '106' => '(?:(?:8(?:5(?:08|4[134]|6[0-35-79]|7[136-8]|3[25]|1[458]|2[12]|5[0-35689]|8[0157-9])|6(?:77|6[158]|5[25]|1[168]|0[18]|2[0256]|8[15]|3[069]|4[0-24589])|0(?:[01]1|39)|7(?:11|97)|401)|6(?:1(?:61|88)|06[06])))',
-    '107' => '(?:(?:8(?:5(?:8[13589]|2[0-24578]|5[0-26-8]|4[356]|3[023]|0[258]|7[0579]|6[0357]|1[15])|6(?:42|8[06]|6[78]|2[023578]|1[15-79]|0[14]|7[46]|3[0-3689]|5[05])|4(?:20|34|56|77|0[134]|8[24]|6[067]|1[04679]|4[08])|3(?:55|4[028]|7[013]|3[1568]|2[0346]|8[08])|0(?:06|77))|6288))',
+    '107' => '(?:8(?:5(?:8[13589]|2[0-24578]|5[0-26-8]|4[356]|3[023]|0[258]|7[0579]|6[0357]|1[15])|6(?:42|8[06]|6[78]|2[023578]|1[15-79]|0[14]|7[46]|3[0-3689]|5[05])|4(?:20|34|56|77|0[134]|8[24]|6[067]|1[04679]|4[08])|3(?:55|4[028]|7[013]|3[1568]|2[0346]|8[08])|0(?:06|77)))',
     '108' => '(?:(?:8(?:5(?:7[01358]|3[02369]|6[124-8]|4[03-578]|5[0-35-9]|0[1-3569]|2[035]|1[0258]|8[013568])|3(?:3[13489]|1[137]|6[0168]|0[357]|7[0-37-9]|5[0158]|8[134689]|4[15]|2[0-35689])|4(?:0[347]|8[45]|6[67]|5[16]|7[478]|2[013-5]|3[029]|1[0-24-7]|4[48])|2(?:4[128]|8[02]|0[1-38]|3[0-4]|5[05]|7[5-8]|1[01]|2[0-28])|6(?:50|1[0-2568]|4[0-2468]|0[126-8]|3[235-8]|2[0-28])|0(?:[25]0|11|8[08]|7[01]|0[15])|7(?:23|1[03]|0[1-37])|117)|63(?:50|63)))',
     '109' => '(?:8792)',
     '110' => '(?:8(?:5(?:6[0-25-7]|5[03589]|4[0134689]|0[1-357-9]|7[35-9]|3[0-79]|1[0-3578]|2[0-478]|8[02-468])|6(?:97|0[2359]|2[0-24-68]|6[0-259]|5[34]|4[245]|1[03-57-9]|3[058]|7[135-8]|8[015-8])|7(?:8[027]|5[057]|1[2-6]|0[168]|4[05]|3[36]|2[1-35])|80[78]|408))',
@@ -133,14 +133,14 @@ our %ZIP_TABLE = (
     '135' => '(?:8(?:5(?:3[0-35]|5\d|7[03-57-9]|8[125-7]|6[035-7]|0[1458]|4[08]|2[1-358]|1[0-478])|4(?:22|4[0358]|0[24]|7[0137]|5[18]|8[0-2]|6[014]|1[15]|3[026])|6(?:02|41|86|2[0-25]|6[168]|3[0-29]|7[0178]|5[059]|1[146-9])|3(?:50|8[3-578]|7[025]|0[13]|2[02]|6[0236]|3[01]|1[0-28])|7(?:3[0-38]|2[0-3]|0[17]|1[0178])|11[0-4]))',
     '136' => '(?:8(?:5(?:4[03]|1[2357]|3[13]|7[057]|5[058]|6[07]|8[0189]|0[1257]|2[1-35])|6(?:[68]6|3[057]|0[357]|7[05]|2[0267]|4[08]|1[125])|7(?:[23]3|11)|405|880|908))',
     '137' => '(?:8(?:6(?:23|50|86)|08[18]|581))',
-    '140' => '(?:8(?:5(?:[89]0|7[1-36]|4[0-37-9]|2[01359]|3[013689]|6[0367]|0[125-8]|5[0-28]|1[1256])|6(?:4[04]|6[0168]|1[13-79]|7[0578]|2[13568]|8[078]|0[157]|3[01479]|5[013568])|7(?:88|1[015-7]|2[12]|0[279])))',
+    '140' => '(?:8(?:5(?:[89]0|7[1-36]|4[0-37-9]|2[01359]|3[013689]|6[0367]|0[125-8]|5[0-28]|1[1256])|6(?:4[04]|0[17]|6[0168]|1[13-79]|7[0578]|2[13568]|8[078]|3[01479]|5[013568])|7(?:88|1[015-7]|2[12]|0[279])))',
     '141' => '(?:8(?:6(?:3[0136-9]|2[01389]|4[0-36-8]|0[2-6]|7[0-36]|1[01568]|8[0136-8]|5[035-8]|6[024-68])|5(?:2[0-2569]|0[13-578]|4[045]|1[024579]|3[03-5]|5[05-79]|6[015-8]|7[1256]|8[02-68])|4(?:2[0-3]|1[1-9])|7(?:0[127]|1[05])|001))',
     '142' => '(?:8(?:5(?:[01]1|22|33|40|67|5[058]|8[58])|6(?:11|39|66)))',
     '143' => '(?:(?:85(?:28|70|3[13589]|8[05]|6[04578]|0[4-8]|4[014]|5[0258]|1[145])|6501))',
     '144' => '(?:8(?:5(?:25|44|5[015]|3[0-356]|7[057]|1[01356]|8[08]|0[56])|6(?:02|35|2[1-3]|5[056]|7[78]|1[014]|6[01])))',
     '145' => '(?:85(?:[23]3|01|58|66|1[15]))',
     '146' => '(?:8(?:5(?:[03]1|22|67|8[058]|7[67]|1[0-2]|5[15]|4[034])|6(?:[03]1|10|2[03]|5[056]|7[78]|6[68])))',
-    '150' => '(?:8(?:3(?:4[03]|7[37]|8[3-5]|1[59]|2[24-8]|0[1367]|5[05]|6[036]|3[038])|5(?:45|3[03]|0[23578]|8[5-7]|2[25]|1[124-7]|6[379]|5[05]|7[57])|4(?:12|36|0[289]|8[28]|5[15]|4[08])|9(?:02|11|40|55|2[35]|3[258])|0(?:[08]1|1[059])|6(?:88|7[237])))',
+    '150' => '(?:8(?:3(?:19|4[03]|7[37]|8[3-5]|2[24-8]|0[1367]|5[05]|6[036]|3[038])|5(?:45|3[03]|0[23578]|8[5-7]|2[25]|1[124-7]|6[379]|5[05]|7[57])|4(?:12|36|0[289]|8[28]|5[15]|4[08])|9(?:02|11|40|55|2[35]|3[258])|0(?:[08]1|1[059])|6(?:88|7[237])))',
     '151' => '(?:8(?:5(?:3\d|8[3-7]|2[1-589]|1[016-9]|6[1-35-9]|4[0-57-9]|5[24589]|7[0-46-8]|9[01]|0[2-579])|6(?:00|7[1-7])|40[14]))',
     '152' => '(?:8(?:5(?:61|4[149]|2[0-257]|0[36-8]|7[08]|1[01]|5[0-28]|3[1-35])|9(?:1[03]|0[24579])|6[02]1))',
     '153' => '(?:8(?:5(?:6[05-7]|2[0-356]|5[0-68]|4[0135]|8[0-25-79]|3[0169]|7[01378]|1[02568]|0[1-689])|6(?:01|20|8[78]|4[01458]|7[07]|6[025689]|5[02-57]|3[013568])|9(?:1[134]|0[246]|2[2357]|3[034679])))',
@@ -149,16 +149,16 @@ our %ZIP_TABLE = (
     '156' => '(?:8(?:5(?:22|33|55|8[578]|0[126]|1[01])|6(?:66|78)))',
     '157' => '(?:85(?:01|43|50|6[1-35-7]|3[05]|2[0-2]|1[01]|7[035]))',
     '158' => '(?:8(?:5(?:0[12589]|5[0-2578]|3[013]|1[0-48]|6[67]|4[349]|2[0235]|7[578]|8[03568])|6(?:28|40|66|1[015]|3[0-3]|0[12])|7[07]1))',
-    '160' => '(?:8(?:3(?:8[39]|4[13]|0[14689]|1[169]|6[1689]|5[1578]|3[013-68]|7[457]|2[14-7])|5(?:30|8[0235-9]|1[0-259]|4[379]|2[0-249]|6[05]|5[57]|7[157]|0[15])|4(?:44|[15][015]|3[13]|2[0-29]|7[27]|0[1-378]|8[457-9])|(?:68|91)0|0(?:01|70)))',
+    '160' => '(?:8(?:3(?:8[39]|4[13]|0[14689]|1[169]|6[1689]|5[1578]|3[013-68]|7[457]|2[14-7])|5(?:30|8[0235-9]|1[0-259]|4[379]|2[0-249]|6[05]|5[57]|7[157]|0[15])|4(?:44|[15][015]|3[13]|7[27]|2[0-39]|0[1-378]|8[457-9])|(?:68|91)0|0(?:01|70)))',
     '161' => '(?:8(?:5(?:08|3[19]|6[057]|5[1-46-8]|2[0158]|7[05]|4[0156]|1[01])|710))',
     '162' => '(?:8(?:6(?:80|3[0368]|5[045]|1[124-6]|6[689]|7[026]|4[046]|0[1248]|2[0246-9])|5(?:8[057]|1[25]|4[013]|7[57]|2[279]|5[16-8]|3[035]|6[0258]|0[1-35])|4(?:33|64|5[015]|0[1257-9]|7[1368]|8[048]|2[12]|4[05689]|1[125])|8(?:30|53|0[1-7]|6[01])|7(?:1[016-8]|0[1578])|0(?:01|22|55)|953))',
     '163' => '(?:(?:0(?:6(?:88|7[5-7]|5[59]|6[3579])|5(?:5[37-9]|6[069]|7[56])|4(?:56|6[067]|7[08])|7(?:77|2[79]|3[013])|8(?:50|67|3[136])|9(?:43|3[589])|2(?:78|6[89]))|1(?:3(?:50|6[38]|8[28]|7[18]|4[589])|4(?:55|70|6[29]|8[08])|0(?:71|5[35]|6[56])|5(?:55|88|3[37]))|8(?:6(?:[18]0|02|26|54|7[127]|3[89]|6[0136])|0(?:0[13]|8[0-2]|1[29])|5(?:35|48)|339)))',
-    '164' => '(?:8(?:5(?:[12]2|[67]7|41|8[58]|5[05]|0[13-5])|6(?:[25]0|[37]8|[68]6|1[17]|4[24])|7(?:01|25)))',
+    '164' => '(?:8(?:5(?:[12]2|[67]7|41|8[58]|5[05]|0[13-5])|6(?:[25]0|[37]8|66|8[26]|1[17]|4[24])|7(?:01|25)))',
     '165' => '(?:8(?:555|780))',
     '166' => '(?:8(?:5(?:20|55|3[13589]|6[5-7]|4[025]|0[1-36]|8[58]|7[078])|6(?:01|10)))',
     '167' => '(?:8(?:5(?:[24]0|85|7[78]|3[34]|6[07]|0[167]|1[05]|5[15])|6(?:10|28|0[12])|0(?:01|70)))',
     '168' => '(?:8(?:5(?:[67]0|85|3[03]|5[058]|0[1-468]|2[05]|1[0-2])|6(?:01|26|[18][16])|081))',
-    '169' => '(?:8(?:5(?:6[018]|2[0-25-7]|8[0568]|4[013]|7[07]|3[0135]|0[37-9]|1[015-7]|5[01568])|6(?:2[04]|5[056]|0[1358]|1[0-36]|7[078]|6[1468]|4[0458]|3[179])|0(?:50|77|1[12])|7(?:[01]1|22)|915))',
+    '169' => '(?:8(?:5(?:6[018]|2[0-25-7]|8[0568]|4[013]|7[07]|3[0135]|0[37-9]|1[015-7]|5[01568])|6(?:2[04]|5[056]|7[78]|0[1358]|1[0-36]|6[1468]|4[0458]|3[179])|0(?:50|77|1[12])|7(?:[01]1|22)|915))',
     '170' => '(?:(?:8(?:4(?:1[015-79]|4[0-2478]|0[124-69]|7[067]|5[015-9]|6[0156]|2[0-467]|8[08]|3[02-468])|6(?:[68]6|12|53|0[25]|3[35])|5(?:51|85)|073)|6080))',
     '171' => '(?:85(?:8[26]|5[02578]|7[027]|4[045]|3[159]|2[0-35-8]|1[0-2468]|6[0189]|0[1-37-9]))',
     '173' => '(?:8(?:5(?:[06]1|30|4[03]|1[0-25-9]|8[058]|5[258])|6(?:48|66|3[29]|1[01]|0[1256])|710))',
@@ -180,13 +180,13 @@ our %ZIP_TABLE = (
     '189' => '(?:85(?:[01]1|85|5[05]|2[01]))',
     '190' => '(?:(?:8(?:5(?:3[015-79]|6[0-25-7]|5[013-578]|8[1-3689]|0[135-9]|7[1-358]|1[013-9]|4[034]|2[0-28])|6(?:66|8[0168]))|129[2357]|0192))',
     '191' => '(?:8(?:5(?:20|55|0[1-35-79]|1[0-2])|6(?:60|86)))',
-    '192' => '(?:(?:8(?:5(?:77|85|3[23578]|2[025]|6[28]|5[1368]|1[0-256]|0[125-8])|6(?:11|22|33|5[015]|4[48])|702)|0(?:9(?:9[2-4]|8[1-3689])|39[2-8])))',
+    '192' => '(?:(?:8(?:5(?:77|85|2[025]|6[28]|5[1368]|1[0-256]|3[235-8]|0[125-8])|6(?:11|22|33|5[015]|4[48])|702)|0(?:9(?:9[2-4]|8[1-3689])|39[2-8])))',
     '193' => '(?:(?:8(?:5(?:[57]0|33|2[05]|1[01]|0[15])|6[68]6)|09(?:85|9[178])))',
     '194' => '(?:(?:8(?:5(?:77|1[015]|4[03]|0[23578]|8[0568]|5[0158]|2[07]|6[067]|3[038])|6(?:66|1[0-2]))|029[2-8]))',
     '195' => '(?:85(?:85|5[05]))',
     '196' => '(?:8(?:5(?:01|22|5[058]|8[58]|1[01])|6(?:[01]1|86|6[68])))',
     '197' => '(?:8(?:5(?:[01]1|55)|6(?:01|23)))',
-    '198' => '(?:8(?:5(?:55|77|2[25]|1[02]|8[58]|3[12])|7(?:[01]1|22|60)|6(?:[01]1|66)))',
+    '198' => '(?:8(?:5(?:55|77|2[25]|1[02]|8[58]|3[12])|7(?:01|22|60|1[01])|6(?:[01]1|66)))',
     '201' => '(?:8(?:5(?:[01]1|8[58])|6(?:01|48|86)))',
     '202' => '(?:85(?:20|85|5[58]))',
     '203' => '(?:8(?:5(?:[12]1|55|8[58])|601|739))',
@@ -373,7 +373,7 @@ our %ZIP_TABLE = (
     '397' => '(?:(?:8(?:5(?:55|67|71|8[58])|60[29])|0[23]92))',
     '398' => '(?:8(?:6(?:86|0[12])|501))',
     '399' => '(?:(?:8(?:7(?:44|60|2[0-258]|5[0145]|1[0-2]|3[0389]|0[1-37])|2(?:9[2357]|8[1-3568])|3(?:86|92)|69[56]|192)|4(?:5(?:6[4-8]|8[13-9]|9[2-578]|7[0-3568])|69[235-7]|39[2-5]|19[25]|498)|0(?:7(?:9[56]|8[1256])|49[235-8]|29[235])|3(?:19[23]|295|797|892)|1(?:392|511|689|895)|9(?:192|393|494)|7192))',
-    '400' => '(?:(?:8(?:5(?:8[568]|0[1568]|1[0-25]|4[03-5]|7[0578]|2[15]|5[05689]|6[56]|3[1356])|6(?:01|10|33|66))|0(?:2(?:80|9[238])|19[2-6]|49[2358]|39[358]|59[238]|69[235])|159[2-478]))',
+    '400' => '(?:(?:8(?:5(?:8[568]|0[1568]|1[0-25]|4[03-5]|7[01578]|2[15]|5[05689]|6[56]|3[1356])|6(?:01|10|33|66))|0(?:2(?:80|9[238])|19[2-6]|49[2358]|39[358]|59[238]|69[235])|159[2-478]))',
     '401' => '(?:(?:0(?:3(?:80|9[5-8])|59[257]|292)|8[56]01))',
     '402' => '(?:85(?:01|55))',
     '403' => '(?:8(?:5(?:22|55)|601))',
@@ -427,7 +427,7 @@ our %ZIP_TABLE = (
     '453' => '(?:8(?:5(?:[56]5|40|77|8[015]|2[12]|0[15]|3[039]|1[0-28])|6(?:[01]1|62|86)|765))',
     '454' => '(?:8(?:5(?:3[03]|2[0-24-79]|5[058]|1[124-9]|6[05]|0[1-689])|651))',
     '455' => '(?:8(?:6(?:[07]1|[46]8|2[06]|3[09])|5(?:[1458]5|21|30|0[15])))',
-    '456' => '(?:8(?:5(?:23|30|55|6[07]|1[16]|8[0578]|0[12])|6(?:20|0[12]|1[0-2]|[68][68])|7(?:11|39|63)))',
+    '456' => '(?:8(?:5(?:23|30|6[07]|1[16]|8[0578]|0[12]|5[56])|6(?:20|0[12]|1[0-2]|[68][68])|7(?:11|39|63)))',
     '457' => '(?:8(?:5(?:[48]5|3[0-35]|[05][158]|2[02]|1[0-25]|7[07]|6[067])|711))',
     '458' => '(?:85(?:30|55|[18][015]|0[1258]|2[0-25]|7[01]))',
     '459' => '(?:85(?:11|22|40))',
@@ -436,7 +436,7 @@ our %ZIP_TABLE = (
     '462' => '(?:8(?:5(?:2[23]|4[03]|7[5-7]|5[158]|0[189]|3[05]|1[129]|8[08])|666))',
     '463' => '(?:85(?:[18]0|5[057]|2[128]|6[0157]|7[157]|0[1-35]|3[03568]|4[013578]))',
     '464' => '(?:8(?:5(?:85|5[058]|2[0-25]|4[035-7]|1[12]|6[0167]|3[01369]|7[017])|6(?:[278]1|[06][1-3]|4[134]|3[1-357]|5[0-4]|1[0135-7])|710))',
-    '465' => '(?:8(?:5(?:20|6[05-7]|5[0-258]|0[15-8]|1[0156])|6(?:51|68|70|1[0-2]|2[026])|701))',
+    '465' => '(?:8(?:5(?:20|6[05-7]|5[0-258]|0[15-8]|1[0156])|6(?:51|68|70|1[0-2]|2[026])))',
     '466' => '(?:8(?:5(?:40|3[39]|6[057]|2[25]|8[058]|1[0-25]|5[0458]|0[125-8])|6(?:73|6[06]|5[05-7]|3[035])|7(?:11|0[17])))',
     '467' => '(?:8(?:5(?:01|6[1-367]|7[17]|3[013]|8[0158]|2[0-25]|5[58]|1[01])|6(?:51|86|2[26]|1[015]|0[1-3]|3[039])))',
     '468' => '(?:8(?:5(?:3[1-46]|2[02]|1[0-4]|8[58]|0[1-7])|626))',
@@ -499,7 +499,7 @@ our %ZIP_TABLE = (
     '527' => '(?:(?:8(?:5(?:[27]7|42|8[058]|6[67]|1[12]|5[0458]|0[589])|687)|0195))',
     '528' => '(?:8(?:5(?:[58]5|0[12]|1[01])|666))',
     '529' => '(?:(?:1(?:3(?:93|8[0-368])|59[2578]|49[235]|69[28]|195|892)|0(?:49[238]|[27]92)))',
-    '530' => '(?:(?:8(?:2(?:6[26]|1[0-257]|8[128]|2[27]|5[12]|4[157]|7[08]|0[13-6]|3[049])|5(?:01|35|44|2[1-3]|8[0238]|6[5-7]|5[1568]|7[45]|1[1-37])|3(?:2[134]|8[389]|4[16]|5[05]|1[18]|[03][48])|6(?:1[018]|0[12]|8[08])|4(?:75|1[015]|4[18])|79[136-8])|6051))',
+    '530' => '(?:(?:8(?:2(?:6[26]|1[0-257]|8[128]|2[27]|5[12]|4[157]|7[08]|0[13-6]|3[049])|5(?:01|35|44|2[1-3]|6[5-7]|5[1568]|7[45]|8[02368]|1[1-37])|3(?:2[134]|8[389]|4[16]|5[05]|1[18]|[03][48])|6(?:1[018]|0[12]|8[08])|4(?:75|1[015]|4[18])|79[136-8])|6051))',
     '531' => '(?:8(?:5(?:11|67|0[1-3]|5[58])|787))',
     '532' => '(?:8(?:5(?:[38]5|60|77|2[045]|0[1578]|5[0258]|1[145])|680))',
     '533' => '(?:8(?:5(?:33|85|5[58]|0[12])|651))',
@@ -776,7 +776,7 @@ our %ZIP_TABLE = (
     '817' => '(?:(?:1(?:[26]92|797)|85(?:20|1[07])))',
     '818' => '(?:(?:8(?:5(?:34|55|67|0[1-3]|1[69]|7[178]|4[09]|8[58])|6(?:42|86|6[68]))|019[2-578]))',
     '819' => '(?:(?:85(?:11|33|85|5[0-258]|0[124])|1(?:19[235]|[36]92)|0(?:39[25]|192)))',
-    '820' => '(?:(?:8(?:5(?:[24]0|33|55|1[02367]|0[125-8])|60[1-357])|0(?:[235]92|69[36]|193)|119[23]))',
+    '820' => '(?:(?:8(?:5(?:[24]0|33|55|1[02367]|0[125-8])|60[1-357])|0(?:[2357]92|69[36]|193)|119[23]))',
     '821' => '(?:8501)',
     '822' => '(?:(?:1(?:29[236]|19[23]|492)|8(?:5(?:[58]5|01)|666)))',
     '823' => '(?:8555)',
@@ -808,7 +808,7 @@ our %ZIP_TABLE = (
     '849' => '(?:(?:85(?:14|22|77|0[1-3]|[58][58])|1(?:[124]92|39[24]|698)|3(?:19[23]|29[23])|419[2-5]|239[235]|519[238]|059[27]))',
     '850' => '(?:8(?:5(?:2[0-35]|8[0568]|1[0-258]|7[057]|5[0158]|0[13-8]|6[0367]|3[0167]|4[013578])|6(?:22|45|7[78]|1[018]|5[02]|6[268]|8[5-8]|0[236])))',
     '851' => '(?:(?:0(?:49[2-478]|19[358]|39[25]|592)|2(?:1(?:85|9[5-8])|29[28]|492)|3(?:39[24]|[25]92)))',
-    '852' => '(?:8(?:5(?:32|66|77|88|1[015]|0[189]|4[24]|5[58]|2[0-378])|601|794))',
+    '852' => '(?:8(?:5(?:32|66|77|88|1[015]|0[17-9]|4[24]|5[58]|2[0-378])|601|794))',
     '853' => '(?:(?:8(?:50[12]|601)|(?:06|2[23])92))',
     '854' => '(?:(?:8(?:5(?:40|55|0[19])|6(?:01|50|66))|0(?:69[26-8]|59[235]|[24]92)))',
     '855' => '(?:8(?:5(?:01|5[05])|686))',
@@ -876,7 +876,7 @@ our %ZIP_TABLE = (
     '919' => '(?:(?:0(?:59[24578]|69[2578]|[124]92|898)|1(?:39[235-7]|[15]92)|2(?:29[2-4]|392)))',
     '920' => '(?:(?:8(?:5(?:0[1-9]|2[0-25]|3[0135-9]|4[014]|7[0357]|1[0-3578]|5[0-46-8]|6[0135-8]|8[035-8])|6(?:0[125-79]|7[0146-8]|2[01356]|8[01568]|5[4-8]|4[0-248]|3[01378]|6[0156]|1[0-69])|7(?:[67]7|30|0[137]|9[13-7]|2[0-289]|1[0189]))|0(?:3(?:8[135-8]|9[23568])|29[235]|192)|1(?:1(?:92|8[0-245])|39[2367])|2(?:39[2-5]|19[256])|3198))',
     '921' => '(?:8(?:5(?:5[0257]|4[14689]|3[0-269]|7[1-9]|2[02-79]|0[15-8]|8[0-47-9]|6[0-2457]|1[0-257-9])|6(?:01|3[079]|1[126]|[25][01])|798))',
-    '922' => '(?:(?:8(?:5(?:30|66|2[25]|8[58]|5[05]|1[01]|0[15])|6(?:09|11|22|50|78|86))|0(?:29[2-578]|19[23]|49[57]|595)))',
+    '922' => '(?:(?:8(?:5(?:01|30|66|2[25]|8[58]|5[05]|1[01])|6(?:09|11|22|50|78|86))|0(?:29[2-578]|19[23]|49[57]|595)))',
     '923' => '(?:(?:8(?:5(?:5[0-257]|8[0168]|3[013]|2[0158]|0[1-357]|6[067]|7[078]|4[14-6]|1[01])|6(?:50|66|2[06]|1[156]|4[2-46]|8[68]|0[135689]|3[039]))|1(?:29[2-7]|198)|039[238]))',
     '924' => '(?:8(?:5(?:01|22|33|44|66|77|8[058]|5[58]|1[01])|68[68]))',
     '925' => '(?:(?:8(?:5(?:30|85|6[67]|5[05]|0[1-3568]|2[15]|1[01])|6(?:[12]0|09|88))|0(?:19[38]|392|498)))',
@@ -905,7 +905,7 @@ our %ZIP_TABLE = (
     '948' => '(?:(?:8(?:50[1-4]|602)|0192))',
     '949' => '(?:(?:7(?:49[24-6]|39[2-4]|59[24]|277)|3(?:29[2-468]|19[2-4]|494)|6(?:69[256]|[124]92|797)|4(?:19[2-4]|392)|5(?:49[2-4]|292)|039[23]|239[24]|8492))',
     '950' => '(?:(?:8(?:5(?:20|6[05-7]|0[1-57]|7[0-25-79]|4[013-5]|5[0135-9]|1[489]|3[0-479]|8[0-35689])|6(?:6[018]|2[0-269]|0[1-368]|5[0145]|7[078]|4[01]|8[016]|[13][039])|7(?:09|5[013589]|2[0-3]|3[023578]|1[01578]|4[014-9]|9[48])|801)|2(?:0(?:8[124-9]|9[235-7])|1(?:8[18]|9[258])|292)|1(?:1(?:9[2-7]|8[1-8])|29[2-8]|49[258])|0(?:19[23568]|292)|3(?:19[58]|393)))',
-    '951' => '(?:8(?:5(?:3[0136]|4[045]|0[13-68]|7[07]|5[0-256]|6[067]|8[01568]|1[0-24589]|2[0-28])|6(?:01|3[23]|8[056]|5[05]|2[029]|1[0-2]|[67][68])))',
+    '951' => '(?:8(?:5(?:3[0136]|4[045]|7[07]|5[0-256]|6[067]|8[01568]|0[1-68]|1[0-24589]|2[0-28])|6(?:01|3[23]|8[056]|5[05]|2[029]|1[0-2]|[67][68])))',
     '952' => '(?:(?:1(?:59[23]|292|393)|850[12]))',
     '953' => '(?:(?:8(?:6(?:66|0[12])|501)|019[23]))',
     '954' => '(?:(?:86(?:19|86)|019[25]))',
@@ -917,7 +917,7 @@ our %ZIP_TABLE = (
     '960' => '(?:(?:8(?:5(?:75|4[06]|0[1-35-8]|1[1258]|8[014589]|5[058]|6[067]|3[0146]|2[0-4])|6(?:48|3[39]|2[056]|7[07]|0[1-357]|6[068]|1[014]|8[68]|5[15]))|0(?:2(?:8[0239]|9[46-8])|1(?:9[245]|8[0145])|69[25]|596|992)|1(?:19[235-8]|29[235-7]|39[23]|[48]92)|2(?:19[3-6]|292)))',
     '961' => '(?:(?:8(?:5(?:22|1[16]|8[58]|0[18])|6(?:11|86|0[12]))|0[134]92))',
     '962' => '(?:(?:8(?:50[1-37-9]|601)|0[2356]92))',
-    '963' => '(?:(?:8(?:5(?:20|4[03]|0[1-36-8]|[13][01359]|6[0346-8]|7[0578]|5[01568]|8[03568])|6(?:[24]2|55|8[569]|7[05-7]|6[014-68]|3[07]|0[129]|1[01])|292|794)|4(?:39[368]|[16]92)|(?:6[1-3]|3[46])92|5(?:49[23]|[16]92)|7(?:796|893)|019[25-8]|138[036-8]))',
+    '963' => '(?:(?:8(?:5(?:20|4[03]|0[1-36-8]|[13][01359]|6[0346-8]|7[0578]|5[01568]|8[03568])|6(?:[24]2|55|8[569]|7[05-7]|6[014-68]|3[07]|0[129]|1[01])|292|794)|4(?:39[368]|[16]92)|(?:6[1-3]|3[46])92|0(?:19[25-8]|296)|5(?:49[23]|[16]92)|7(?:796|893)|138[036-8]))',
     '964' => '(?:(?:8(?:5(?:[67]7|01|58)|601)|0[23]92))',
     '965' => '(?:8(?:5(?:[34]0|67|[58][058]|2[02]|0[1-356]|7[07]|1[016])|6(?:[01]1|78)))',
     '966' => '(?:(?:0(?:19[2-4]|485)|8601))',
